Welcome to NABQR's Documentation
==============================

NABQR (Neural Adaptive Basis Quantile Regression) is a method for sequential error-corrections 
tailored for wind power forecasting in Denmark.

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   readme
   installation
   usage

.. toctree::
   :maxdepth: 2
   :caption: API Documentation

   modules

.. toctree::
   :maxdepth: 1
   :caption: Development

   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
